@@ -39,7 +39,7 @@ able to narrow down the possibilities.
 
 import tempfile, errno, signal, cPickle, C
 from static import *
-from rpath import *
+
 
 class RobustAction:
 	"""Represents a file operation to be accomplished later"""
@@ -247,29 +247,38 @@ class Robust:
 	def check_common_error(error_handler, function, args = []):
 		"""Apply function to args, if error, run error_handler on exception
 
-		This only catches certain exceptions which seems innocent
-		enough.
+		This uses the catch_error predicate below to only catch
+		certain exceptions which seems innocent enough.
 
 		"""
 		try: return function(*args)
- 		except (EnvironmentError, SkipFileException, DSRPPermError,
-				RPathException, Rdiff.RdiffException,
-				librsync.librsyncError, C.UnknownFileTypeError), exc:
-			TracebackArchive.add()
-			if (not isinstance(exc, EnvironmentError) or
-				(errno.errorcode[exc[0]] in
-				 ['EPERM', 'ENOENT', 'EACCES', 'EBUSY', 'EEXIST',
-				  'ENOTDIR', 'ENAMETOOLONG', 'EINTR', 'ENOTEMPTY',
-				  'EIO', 'ETXTBSY', 'ESRCH', 'EINVAL'])):
+		except Exception, exc:
+			TracebackArchive.add([function] + list(args))
+			if Robust.catch_error(exc):
 				Log.exception()
 				conn = Globals.backup_writer
 				if conn is not None: # increment error count
 					ITRB_exists = conn.Globals.is_not_None('ITRB')
 					if ITRB_exists: conn.Globals.ITRB.increment_stat('Errors')
 				if error_handler: return error_handler(exc, *args)
-			else:
-				Log.exception(1, 2)
-				raise
+				else: return
+			Log.exception(1, 2)
+			raise
+
+	def catch_error(exc):
+		"""Return true if exception exc should be caught"""
+		for exception_class in (SkipFileException, DSRPPermError,
+								RPathException, Rdiff.RdiffException,
+								librsync.librsyncError,
+								C.UnknownFileTypeError):
+			if isinstance(exc, exception_class): return 1
+		if (isinstance(exc, EnvironmentError) and
+			errno.errorcode[exc[0]] in ('EPERM', 'ENOENT', 'EACCES', 'EBUSY',
+										'EEXIST', 'ENOTDIR', 'ENAMETOOLONG',
+										'EINTR', 'ENOTEMPTY', 'EIO', 'ETXTBSY',
+										'ESRCH', 'EINVAL')):
+			return 1
+		return 0
 
 	def listrp(rp):
 		"""Like rp.listdir() but return [] if error, and sort results"""
@@ -300,16 +309,21 @@ class SignalException(Exception):
 class TracebackArchive:
 	"""Save last 10 caught exceptions, so they can be printed if fatal"""
 	_traceback_strings = []
-	def add(cls):
-		"""Add most recent exception to archived list"""
-		cls._traceback_strings.append(Log.exception_to_string())
+	def add(cls, extra_args = []):
+		"""Add most recent exception to archived list
+
+		If extra_args are present, convert to strings and add them as
+		extra information to same traceback archive.
+
+		"""
+		cls._traceback_strings.append(Log.exception_to_string(extra_args))
 		if len(cls._traceback_strings) > 10:
 			cls._traceback_strings = cls._traceback_strings[:10]
 
 	def log(cls):
 		"""Print all exception information to log file"""
 		if cls._traceback_strings:
-			Log("------------ Old traceback info -----------\n%s"
+			Log("------------ Old traceback info -----------\n%s\n"
 				"-------------------------------------------" %
 				("\n".join(cls._traceback_strings),), 3)
 
@@ -607,8 +621,9 @@ class Resume:
 		data = fp.read()
 		fp.close()
 		try: result = cPickle.loads(data)
-		except cPickle.UnpicklingError:
-			raise ResumeException("Bad pickle at %s" % (checkpoint_rp.path,))
+		except Exception, exc:
+			raise ResumeException("Bad pickle at %s: %s" %
+								  (checkpoint_rp.path, exc))
 		return result
 
 	def ResumeCheck(cls):
@@ -672,3 +687,4 @@ from log import *
 from destructive_stepping import *
 import Time, Rdiff, librsync
 from highlevel import *
+
