@@ -20,16 +20,6 @@ import os, stat, re, sys, shutil, gzip, socket
 from static import *
 
 
-class SkipFileException(Exception):
-	"""Signal that the current file should be skipped but then continue
-
-	This exception will often be raised when there is problem reading
-	an individual file, but it makes sense for the rest of the backup
-	to keep going.
-
-	"""
-	pass
-
 class RPathException(Exception): pass
 
 class RPathStatic:
@@ -850,6 +840,7 @@ import FilenameMapping
 from lazy import *
 from selection import *
 from destructive_stepping import *
+from highlevel import *
 
 class RpathDeleter(ITRBranch):
 	"""Delete a directory.  Called by RPath.delete()"""
